pub struct PrefixedId { /* private fields */ }Implementations
Sourceimpl PrefixedId
impl PrefixedId
Sourcepub fn new(prefix: IdPrefix, value: &str) -> Result<PrefixedId, IdPrefixError>
pub fn new(prefix: IdPrefix, value: &str) -> Result<PrefixedId, IdPrefixError>
Creates a prefixed identifier from a validated prefix and value.
Errors
Returns IdPrefixError::EmptyValue when the trimmed value is empty and
IdPrefixError::InvalidValueCharacter when it contains unsupported characters.
Sourcepub fn parse(input: &str) -> Result<PrefixedId, IdPrefixError>
pub fn parse(input: &str) -> Result<PrefixedId, IdPrefixError>
Parses the canonical prefix_value representation.
Errors
Returns IdPrefixError::MissingSeparator when the input does not contain _ and the
corresponding prefix or value validation error for malformed parts.
pub const fn prefix(&self) -> &IdPrefix
pub fn value(&self) -> &str
pub fn into_parts(self) -> (IdPrefix, String)